<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Request;

// Import framework stuff
use Org\Mxchange\CoreFramework\Generic\FrameworkInterface;

/**
 * An interface for requests
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2020 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface Requestable extends FrameworkInterface {
	/**
	 * Checks whether a request element is set
	 *
	 * @param	$element	Name of the request element we want to check
	 * @return	$isSet		Whether the request element is set
	 */
	function isRequestElementSet (string $element);

	/**
	 * Getter for request element or 'null' if element was not found
	 *
	 * @param	$element	Name of the request element we want to check
	 * @return	$value		Value of the found request element or 'null' if the
	 *						element was not found
	 */
	function getRequestElement (string $element);

	/**
	 * Setter for request elements
	 *
	 * @param	$element	Request element to se
	 * @param	$value		Value to set
	 * @return	void
	 */
	function setRequestElement (string $element, $value);

	/**
	 * Setter for request data array
	 *
	 * @param	$requestData	Request element to se
	 * @return	void
	 */
	function setRequestData (array $requestData);

	/**
	 * Wrapper method for array_key() function for the request data array
	 *
	 * @return	$array	An array containing all array keys to return
	 */
	function getParameterNames ();

	/**
	 * Sets whether the request was valid (default: true)
	 *
	 * @param	$isValid	Whether the request is valid
	 * @return	void
	 */
	function requestIsValid (bool $isValid = true);

	/**
	 * Returns whether this request is valid
	 *
	 * @return	$requestIsValid		Whether this request is valid
	 */
	function isRequestValid ();

}
